RandomAnchorSelection
=====================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: RandomAnchorSelection
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RandomAnchorSelection.rank

   .. rubric:: Methods Documentation

   .. automethod:: rank
